/*
 * File:   main.c
 * Author: justinbauer@mcuhq.com
 *
 * Created on April 7, 2016, 9:43 PM
 */


#include <xc.h>

// #pragma config statements should precede project file includes.
// Use project enums instead of #define for ON and OFF.

// CONFIG1
#pragma config FOSC = INTOSC    // Oscillator Selection Bits (INTOSC oscillator: I/O function on CLKIN pin)
#pragma config WDTE = OFF       // Watchdog Timer Enable (WDT disabled)
#pragma config PWRTE = OFF      // Power-up Timer Enable (PWRT disabled)
#pragma config MCLRE = ON       // MCLR Pin Function Select (MCLR/VPP pin function is MCLR)
#pragma config CP = OFF         // Flash Program Memory Code Protection (Program memory code protection is disabled)
#pragma config BOREN = ON       // Brown-out Reset Enable (Brown-out Reset enabled)
#pragma config CLKOUTEN = OFF   // Clock Out Enable (CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin)
#pragma config IESO = ON        // Internal/External Switchover Mode (Internal/External Switchover Mode is enabled)
#pragma config FCMEN = ON       // Fail-Safe Clock Monitor Enable (Fail-Safe Clock Monitor is enabled)

// CONFIG2
#pragma config WRT = OFF        // Flash Memory Self-Write Protection (Write protection off)
#pragma config PPS1WAY = ON     // Peripheral Pin Select one-way control (The PPSLOCK bit cannot be cleared once it is set by software)
#pragma config ZCDDIS = ON      // Zero-cross detect disable (Zero-cross detect circuit is disabled at POR)
#pragma config PLLEN = ON       // Phase Lock Loop enable (4x PLL is always enabled)
#pragma config STVREN = ON      // Stack Overflow/Underflow Reset Enable (Stack Overflow or Underflow will cause a Reset)
#pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (Vbor), low trip point selected.)
#pragma config LPBOR = OFF      // Low-Power Brown Out Reset (Low-Power BOR is disabled)
#pragma config LVP = ON         // Low-Voltage Programming Enable (Low-voltage programming enabled)

#include "lcd.h"
#include <stdio.h>
#include <string.h>

void main(void) {

    // 32MHz setup
    OSCCONbits.SPLLEN = 1; // enable PLL
    OSCCONbits.IRCF = 0b1110; // 8MHz (32MHz when PLL enabled)
    
    // Pin init
    TRISC = TRISB = 0;   // Set all pins as outputs
    ANSELC = ANSELB = 0; // Set pins as digital
    WPUC = WPUB = 0; // Disable the weak internal pull-ups
    LATB = LATC = 0; // Start with all pins driven LOW


    initLCD();
    gotoLCD(FIRST_LINE);
    printf("  Hello World");
    gotoLCD(SECOND_LINE);
    printf("** mcuhq.com **");
    //gotoLCD(SECOND_LINE);

    while (1) {
        LATCbits.LATC0 ^= 1;
        __delay_ms(1000);
    }
}

void putch(char c) {
    lcdWrite(c, DATA);
}
